@@ -24,6 +24,7 @@
 #' @param ... additional parameters passed to \code{\link{Pandoc.convert}}
 #' @note Only one of the input parameters (\code{file} or \code{text}) is to be used at once!
 #' @export
+#' @importFrom utils tail head capture.output
 #' @return converted file name with full path if \code{convert} is set, none otherwise
 #' @references \itemize{
 #'      \item Jeffrey Horner (2011). _brew: Templating Framework for Report Generation._ \url{http://CRAN.R-project.org/package=brew}
@@ -59,32 +60,41 @@
 #' str(Pandoc.brew(text='<%for (i in 1:5) {%>
 #' Pi has a lot (<%=i%>) of power: <%=pi^i%><%}%>'))
 #' }
-Pandoc.brew <- function(file = stdin(), output = stdout(), convert = FALSE, open = TRUE, graph.name, graph.dir, graph.hi.res = FALSE, text = NULL, envir = parent.frame(), append = FALSE, ...) {
+Pandoc.brew <- function(file = stdin(), output = stdout(), convert = FALSE, open = TRUE,
+                        graph.name, graph.dir, graph.hi.res = FALSE, text = NULL,
+                        envir = parent.frame(), append = FALSE, ...) {
 
     timer <- proc.time()
     output.stdout <- deparse(substitute(output)) == 'stdout()'
 
-    if (identical(convert, FALSE))
+    if (identical(convert, FALSE)) {
         open <- FALSE
-    else
-        if (output.stdout)
+    } else {
+        if (output.stdout) {
             stop('A file name should be provided while converting a document.')
+        }
+    }
 
     if (!output.stdout) {
         basedir    <- dirname(output)
-        if (missing(graph.name))
+        if (missing(graph.name)) {
             graph.name <- paste0(basename(output), '-%n')
-        if (missing(graph.dir))
+        }
+        if (missing(graph.dir)) {
             graph.dir  <- file.path(basedir, 'plots')
+        }
     } else {
-        if (missing(graph.name))
+        if (missing(graph.name)) {
             graph.name <- '%t'
-        if (missing(graph.dir))
+        }
+        if (missing(graph.dir)) {
             graph.dir  <- file.path(tempdir(), 'plots')
+        }
     }
 
-    if (is.null(text))
+    if (is.null(text)) {
         text <- paste(readLines(file, warn = FALSE), collapse = '\n')
+    }
 
     ## id of chunk
     assign('cmdID', 0, envir = debug)
@@ -104,9 +114,14 @@ Pandoc.brew <- function(file = stdin(), output = stdout(), convert = FALSE, open
         ## format 'em
         for (r in res) {
 
-            r.pander <- tryCatch(pander.return(r), error = function(e) e)
-            if (inherits(r.pander, 'error'))
-                r.pander <- paste0('Internal `pander` error: `', r.pander$message, '` while running: `', r$src,'`\n\nPlease [report the issue](https://github.com/Rapporter/pander/issues/new) with a reproducible example to help developers fix this ASAP.')
+            r.pander <- tryCatch(pander_return(r), error = function(e) e)
+            if (inherits(r.pander, 'error')) {
+                r.pander <- paste0('Internal `pander` error: `',
+                                   r.pander$message,
+                                   '` while running: `',
+                                   r$src,
+                                   '`\n\nPlease [report the issue](https://github.com/Rapporter/pander/issues/new) with a reproducible example to help developers fix this ASAP.') #nolint
+            }
             r$output <- r.pander
             cat(paste(r.pander, collapse = '\n'))
 
@@ -114,19 +129,28 @@ Pandoc.brew <- function(file = stdin(), output = stdout(), convert = FALSE, open
             localstorage.last <- tail(localstorage, 1)[[1]]
             localstorage.last.text <- ifelse(is.null(localstorage.last$text$eval), '', localstorage.last$text$eval)
 
-            if (('image' %in% r$type) | (length(r.pander) > 1) | grepl('\n$', localstorage.last.text) | is.null(localstorage.last$text$eval))
+            if ('image' %in% r$type
+                || length(r.pander) > 1
+                || grepl('\n$', localstorage.last.text)
+                || is.null(localstorage.last$text$eval)) {
                 type <- 'block'
-            else
+            } else {
                 type <- 'inline'
+            }
 
             if (type == 'inline') {
 
-                localstorage[[length(localstorage)]]$text <- list(raw = paste0(localstorage.last$text$raw, paste0('<%=', r$src, '%>')), eval = paste0(localstorage.last$text$eval, r.pander))
-                localstorage[[length(localstorage)]]$chunks <- list(raw = c(localstorage.last$chunks$raw, paste0('<%=', r$src, '%>')), eval = c(localstorage.last$chunks$eval, ifelse(length(r.pander) == 0, '', r.pander)))
-                localstorage[[length(localstorage)]]$msg <- list(messages = c(localstorage.last$msg$messages, r$msg$messages), warnings = c(localstorage.last$msg$warnings, r$msg$warnings), errors = c(localstorage.last$msg$errors, r$msg$errors))
+                localstorage[[length(localstorage)]]$text <- list(raw = paste0(localstorage.last$text$raw, paste0('<%=', r$src, '%>')), #nolint
+                                                                  eval = paste0(localstorage.last$text$eval, r.pander)) #nolint
+                localstorage[[length(localstorage)]]$chunks <- list(raw = c(localstorage.last$chunks$raw, paste0('<%=', r$src, '%>')), #nolint
+                                                                    eval = c(localstorage.last$chunks$eval, ifelse(length(r.pander) == 0, '', r.pander))) #nolint
+                localstorage[[length(localstorage)]]$msg <- list(messages = c(localstorage.last$msg$messages, r$msg$messages), #nolint
+                                                                 warnings = c(localstorage.last$msg$warnings, r$msg$warnings), #nolint
+                                                                 errors = c(localstorage.last$msg$errors, r$msg$errors)) #nolint
 
-            } else
+            } else {
                 localstorage <- c(localstorage, list(list(type = 'block', robject = r)))
+            }
 
             assign('.storage', localstorage, envir = envir)
 
@@ -138,13 +162,15 @@ Pandoc.brew <- function(file = stdin(), output = stdout(), convert = FALSE, open
     res <- capture.output(brew(text = text, envir = envir))
 
     ## remove absolute path from image links
-    if (!output.stdout)
+    if (!output.stdout) {
         res <- gsub(sprintf(']\\(%s/', basedir), ']\\(', res, fixed = TRUE)
+    }
 
     cat(remove.extra.newlines(paste(res, collapse = '\n')), '\n', file = output, append = append)
 
-    if (is.character(convert))
+    if (is.character(convert)) {
         Pandoc.convert(output, format = convert, open = open, proc.time = as.numeric(proc.time() - timer)[3], ...)
+    }
 
     ## remove trailing line-break text
     ## if (tail(get('.storage', envir = envir), 1)[[1]]$text$eval == '\n')
@@ -154,8 +180,9 @@ Pandoc.brew <- function(file = stdin(), output = stdout(), convert = FALSE, open
     assign('chunkID', NULL, envir = debug)
     assign('cmdID', NULL, envir = debug)
     assign('nested', debug$nested - 1, envir = debug)
-    if (debug$nested == 0)
+    if (debug$nested == 0) {
         assign('nestedID', 0, envir = debug)
+    }
 
     invisible(get('.storage', envir = envir))
 
@@ -172,10 +199,10 @@ BRCODE <- 2
 BRCOMMENT <- 3
 BRCATCODE <- 4
 DELIM <- list()
-DELIM[[BRTEXT]] <- c("","")
-DELIM[[BRCODE]] <- c("<%","%>")
-DELIM[[BRCOMMENT]] <- c("<%#","%>")
-DELIM[[BRCATCODE]] <- c("<%=","%>")
+DELIM[[BRTEXT]] <- c('','')
+DELIM[[BRCODE]] <- c('<%','%>')
+DELIM[[BRCOMMENT]] <- c('<%#','%>')
+DELIM[[BRCATCODE]] <- c('<%=','%>')
 
 #' Patched brew
 #'
@@ -195,16 +222,18 @@ DELIM[[BRCATCODE]] <- c("<%=","%>")
 #' @keywords internal
 `brew` <- function(text = NULL, envir = parent.frame()) {
 
-    if (is.character(text) && nchar(text[1]) > 0)
+    if (is.character(text) && nchar(text[1]) > 0) {
         icon <- textConnection(text[1])
-    else
+    } else {
         stop('Invalid input.')
+    }
 
-    if (!is.environment(envir))
+    if (!is.environment(envir)) {
         stop('Invalid environment')
+    }
 
     state <- BRTEXT
-    text <- code <- tpl <- character(0)
+    text <- code <- character(0)
     textLen <- codeLen <- as.integer(0)
     textStart <- as.integer(1)
     line <- ''
@@ -212,8 +241,10 @@ DELIM[[BRCATCODE]] <- c("<%=","%>")
     while(TRUE){
         if (!nchar(line)){
             line <- readLines(icon,1)
-            if (length(line) != 1) break
-            line <- paste(line,"\n",sep='')
+            if (length(line) != 1){
+                break
+            }
+            line <- paste(line,'\n',sep='')
         }
         if (state == BRTEXT){
 
@@ -223,7 +254,7 @@ DELIM[[BRCATCODE]] <- c("<%=","%>")
             if (length(spl) > 1){
 
                 if (nchar(spl[1])) {
-                    text[textLen+1] <- spl[1]
+                    text[textLen + 1] <- spl[1]
                     textLen <- textLen + 1
                 }
                 line <- paste(spl[-1],collapse='<%')
@@ -240,46 +271,49 @@ DELIM[[BRCATCODE]] <- c("<%=","%>")
                 }
 
                 if (textStart <= textLen) {
-                    code[codeLen+1] <- paste('showText(',textStart,',',textLen,')',sep='')
+                    code[codeLen + 1] <- paste('showText(',textStart,',',textLen,')',sep='')
                     codeLen <- codeLen + 1
                     textStart <- textLen + 1
                 }
             } else {
-                text[textLen+1] <- line
+                text[textLen + 1] <- line
                 textLen <- textLen + 1
                 line <- ''
             }
         } else {
-            if (regexpr("%>",line,perl=TRUE) > 0){
-                spl <- strsplit(line,"%>",fixed=TRUE)[[1]]
+            if (regexpr('%>',line,perl=TRUE) > 0){
+                spl <- strsplit(line,'%>',fixed=TRUE)[[1]]
                 line <- paste(spl[-1],collapse='%>')
 
                 n <- nchar(spl[1])
                 ## test  for '-' immediately preceding %> will strip trailing newline from line
                 if (n > 0) {
                     if (substr(spl[1],n,n) == '-') {
-                        line <- substr(line,1,nchar(line)-1)
-                        spl[1] <- substr(spl[1],1,n-1)
+                        line <- substr(line,1,nchar(line) - 1)
+                        spl[1] <- substr(spl[1],1,n - 1)
                     }
-                    text[textLen+1] <- spl[1]
+                    text[textLen + 1] <- spl[1]
                     textLen <- textLen + 1
                 }
 
                 ## We've found the end of a brew section, but we only care if the
                 ## section is a BRCODE or BRCATCODE. We just implicitly drop BRCOMMENT sections
                 if (state == BRCODE){
-                    code[codeLen+1] <- paste(text[textStart:textLen],collapse='')
+                    code[codeLen + 1] <- paste(text[textStart:textLen],collapse='')
                     codeLen <- codeLen + 1
                 } else if (state == BRCATCODE){
-                    code[codeLen + 1] <- paste0("showCode(", deparse(paste(text[textStart:textLen], collapse = "\n")), ")")
+                    code[codeLen + 1] <- paste0('showCode(',
+                                                deparse(paste(text[textStart:textLen],collapse = '\n')), ')')
                     codeLen <- codeLen + 1
                 }
                 textStart <- textLen + 1
                 state <- BRTEXT
-            } else if (regexpr("<%",line,perl=TRUE) > 0){
-                stop("Oops! Someone forgot to close a tag. We saw: ",DELIM[[state]][1],' and we need ',DELIM[[state]][2])
+            } else if (regexpr('<%',line,perl=TRUE) > 0){
+                stop('Oops! Someone forgot to close a tag. We saw: ',
+                     DELIM[[state]][1],' and we need ',
+                     DELIM[[state]][2])
             } else {
-                text[textLen+1] <- line
+                text[textLen + 1] <- line
                 textLen <- textLen + 1
                 line <- ''
             }
@@ -287,12 +321,14 @@ DELIM[[BRCATCODE]] <- c("<%=","%>")
     }
     if (state == BRTEXT){
         if (textStart <= textLen) {
-            code[codeLen+1] <- paste('showText(',textStart,',',textLen,')',sep='')
+            code[codeLen + 1] <- paste('showText(',textStart,',',textLen,')',sep='')
             codeLen <- codeLen + 1
             textStart <- textLen + 1
         }
     } else {
-        stop("Oops! Someone forgot to close a tag. We saw: ",DELIM[[state]][1],' and we need ',DELIM[[state]][2], call. = FALSE)
+        stop('Oops! Someone forgot to close a tag. We saw: ',
+             DELIM[[state]][1],' and we need ',
+             DELIM[[state]][2], call. = FALSE)
     }
 
     showText <- function(from, to) {
@@ -303,11 +339,12 @@ DELIM[[BRCATCODE]] <- c("<%=","%>")
             cat(localtext)
 
             if (grepl('^#+[ \t]+', localtext)) {
-                heading.level <- nchar(gsub("^(#{1,6})[ \t]+.*", "\\1", localtext))
+                heading.level <- nchar(gsub('^(#{1,6})[ \t]+.*', '\\1', localtext))
                 localtext <- gsub('^#{1,6}[ \t]+', '', localtext)
                 type <- 'heading'
-            } else
+            } else {
                 type <- 'text'
+            }
 
             localstorage <- get('.storage', envir = envir)
             localstorage.last <- tail(localstorage, 1)[[1]]
@@ -318,7 +355,7 @@ DELIM[[BRCATCODE]] <- c("<%=","%>")
                 localstorage.last.pander  <- localstorage.last$robject$output
 
                 ## we had an inline chunk in the beginning of the line converted to block
-                if (!('image' %in% localstorage.last$robject$type) & (length(localstorage.last.pander) <= 1))
+                if (!'image' %in% localstorage.last$robject$type && length(localstorage.last.pander) <= 1) {
                     localstorage <- c(localstorage[-length(localstorage)],
                                       list(list(type = 'text',
                                            text = list(
@@ -333,26 +370,35 @@ DELIM[[BRCATCODE]] <- c("<%=","%>")
                                                warnings = localstorage.last$robject$msg$warnings,
                                                errors   = localstorage.last$robject$msg$errors
                                                ))))
-
+                } else {
                 ## leave that block as is and add localtext as new
-                else
-
-                    localstorage <- c(localstorage, list(list(type = type, text = list(raw = localtext, eval = localtext), chunks = list(raw = NULL, eval = NULL), msg = list(messages = NULL, warnings = NULL, errors = NULL))))
+                    localstorage <- c(localstorage,
+                                      list(list(type = type,
+                                                text = list(raw = localtext, eval = localtext),
+                                                chunks = list(raw = NULL, eval = NULL),
+                                                msg = list(messages = NULL, warnings = NULL, errors = NULL))))
+                }
 
             } else {
 
                 ## text continues
-                if (is.character(localstorage.last.text) & (type == 'text') & ifelse(localstorage.last.type == 'heading', !grepl('\n', localstorage.last.text), TRUE))
-                    localstorage[[length(localstorage)]]$text <- list(raw = paste0(localstorage.last$text$raw, localtext), eval = paste0(localstorage.last.text, localtext))
-
+                if (is.character(localstorage.last.text) &&
+                    (type == 'text') &&
+                    ifelse(localstorage.last.type == 'heading', !grepl('\n', localstorage.last.text), TRUE)) {
+                    localstorage[[length(localstorage)]]$text <- list(raw = paste0(localstorage.last$text$raw, localtext), eval = paste0(localstorage.last.text, localtext)) #nolint
+                } else {
                 ## new text starts here
-                else
-                    localstorage <- c(localstorage, list(list(type = type, text = list(raw = localtext, eval = localtext), chunks = list(raw = NULL, eval = NULL), msg = list(messages = NULL, warnings = NULL, errors = NULL))))
-
+                    localstorage <- c(localstorage,
+                                      list(list(type = type,
+                                                text = list(raw = localtext, eval = localtext),
+                                                chunks = list(raw = NULL, eval = NULL),
+                                                msg = list(messages = NULL, warnings = NULL, errors = NULL))))
+                }
             }
 
-            if (type == 'heading')
+            if (type == 'heading') {
                 localstorage[[length(localstorage)]]$level <- heading.level
+            }
 
             assign('.storage', localstorage, envir = envir)
 
@@ -372,16 +418,20 @@ DELIM[[BRCATCODE]] <- c("<%=","%>")
         brcodes <- code[!grepl('^show', code)]
         if (length(brcodes) > 0) {
             brcodes <- p(brcodes, wrap = '`')
-            if (grepl('[Uu]nexpected', msg))
-                stop(paste0('`', sub('.*([Uu]nexpected [a-zA-Z0-9\\(\\)\'\\{\\} ]*)( at character|\n).*', '\\1', msg), '` in your BRCODEs: ', brcodes), call. = FALSE)
-            else
+            if (grepl('[Uu]nexpected', msg)) {
+                stop(paste0('`',
+                            sub('.*([Uu]nexpected [a-zA-Z0-9\\(\\)\'\\{\\} ]*)( at character|\n).*', '\\1', msg),
+                            '` in your BRCODEs: ', brcodes), call. = FALSE)
+            } else {
                 stop(sprintf('Error (`%s`) in your BRCODEs: %s', msg, brcodes), call. = FALSE)
-        } else
+            }
+        } else {
 
             stop(paste0('Error: ', p(msg, wrap = '`')), call. = FALSE)
-
-    } else
+        }
+    } else {
         assign('last', list(code = code, text = text, result = e), envir = debug) # debug
+    }
 
     ## safety check: not leaving any `sink` open
     ## while (sink.number() != 0)
