@@ -3,15 +3,16 @@ ess.pander.evals <- function(x, show.src = TRUE) {
     require(pander, quietly = T)
     wd <- getwd()
     setwd(tempdir())
-    cat("\n")
+    cat('\n')
     res <- evals(x)
     for (x in res) {
-        if (show.src)
+        if (show.src) {
             cat('\n```r\n', paste(x$src, collapse = '\n'), '\n```\n\n', sep ='')
+        }
         cat(pander(x), sep = '\n')
     }
     setwd(wd)
-    cat("\n")
+    cat('\n')
 }
 
 #' @keywords internal
@@ -19,8 +20,8 @@ ess.evals <- function(x) {
     require(pander, quietly = T)
     wd <- getwd()
     setwd(tempdir())
-    cat("\n")
+    cat('\n')
     evals(x)
     setwd(wd)
-    cat("\n")
+    cat('\n')
 }
