@@ -40,33 +40,36 @@ repChar <- function(x, n, sep = '')
 #'
 #' \code{\link{p}} merges elements of a vector in one string for the sake of pretty inline printing. Default parameters are read from appropriate \code{option} values (see argument description for details). This function allows you to put the results of an expression that yields a variable \emph{inline}, by wrapping the vector elements with the string provided in \code{wrap}, and separating elements by main and ending separator (\code{sep} and \code{copula}). In case of a two-length vector, value specified in \code{copula} will be used as a separator. You can also control the length of provided vector by altering an integer value specified in \code{limit} argument (defaults to \code{Inf}).
 #' @param x an atomic vector to get merged for inline printing
-#' @param wrap a string to wrap vector elements (uses value set in \code{p.wrap} option: \code{"_"} by default, which is a markdown-friendly wrapper and it puts the string in \emph{italic})
-#' @param sep a string with the main separator, i.e. the one that separates all vector elements but the last two (uses the value set in \code{p.sep} option - \code{","} by default)
-#' @param copula a string with ending separator - the one that separates the last two vector elements (uses the value set in \code{p.copula} option, \code{"and"} by default)
+#' @param wrap a string to wrap vector elements (uses value set in \code{p.wrap} option: \code{'_'} by default, which is a markdown-friendly wrapper and it puts the string in \emph{italic})
+#' @param sep a string with the main separator, i.e. the one that separates all vector elements but the last two (uses the value set in \code{p.sep} option - \code{','} by default)
+#' @param copula a string with ending separator - the one that separates the last two vector elements (uses the value set in \code{p.copula} option, \code{'and'} by default)
 #' @param limit maximum character length (defaults to \code{Inf}initive  elements)
 #' @param keep.trailing.zeros to show or remove trailing zeros in numbers
 #' @param missing string to replace missing values
+#' @param digits numeric (default: 2) passed to format
+#' @param round numeric (default: Inf) passed to round
 #' @return a string with concatenated vector contents
 #' @examples
-#' p(c("fee", "fi", "foo", "fam"))
-#' ## [1] "_fee_, _fi_, _foo_ and _fam_"
-#' p(1:3, wrap = "")
-#' ## [1] "1, 2 and 3"
-#' p(LETTERS[1:5], copula = "and the letter")
-#' ## [1] "_A_, _B_, _C_, _D_ and the letter _E_"
-#' p(c("Thelma", "Louise"), wrap = "", copula = "&")
-#' ## [1] "Thelma & Louise"
+#' p(c('fee', 'fi', 'foo', 'fam'))
+#' ## [1] '_fee_, _fi_, _foo_ and _fam_'
+#' p(1:3, wrap = '')
+#' ## [1] '1, 2 and 3'
+#' p(LETTERS[1:5], copula = 'and the letter')
+#' ## [1] '_A_, _B_, _C_, _D_ and the letter _E_'
+#' p(c('Thelma', 'Louise'), wrap = '', copula = '&')
+#' ## [1] 'Thelma & Louise'
 #' @export
 #' @author Aleksandar Blagotic
 #' @references This function was moved from \code{rapport} package: \url{http://rapport-package.info}.
-p <- function(x, wrap = panderOptions('p.wrap'), sep = panderOptions('p.sep'), copula = panderOptions('p.copula'), limit = Inf, keep.trailing.zeros = panderOptions('keep.trailing.zeros'), missing = panderOptions('missing')){
+p <- function(x, wrap = panderOptions('p.wrap'), sep = panderOptions('p.sep'), copula = panderOptions('p.copula'), limit = Inf, keep.trailing.zeros = panderOptions('keep.trailing.zeros'), missing = panderOptions('missing'), digits = panderOptions('digits'), round = panderOptions('round')){ #nolint
 
     attributes(x) <- NULL
     stopifnot(is.vector(x))
     stopifnot(all(sapply(list(wrap, sep, copula), function(x) is.character(x) && length(x) == 1)))
     x.len <- length(x)
-    if (x.len == 0)
+    if (x.len == 0) {
         return('')
+    }
     stopifnot(x.len <= limit)
 
     ## store missing values
@@ -75,27 +78,30 @@ p <- function(x, wrap = panderOptions('p.wrap'), sep = panderOptions('p.sep'), c
     ## prettify numbers
     if (is.numeric(x)) {
 
-        x <- round(x, panderOptions('round'))
+        x <- round(x, digits = round)
 
         ## optionally remove trailing zeros by running format separately on each element of the vector
-        if (!keep.trailing.zeros)
-            x <- sapply(x, format, trim = TRUE, digits = panderOptions('digits'), decimal.mark = panderOptions('decimal.mark'))
-        ## otherwise force using the same number format for all vector elements
-        else
-            x <- format(x, trim = TRUE, digits = panderOptions('digits'), decimal.mark = panderOptions('decimal.mark'))
+        if (!keep.trailing.zeros) {
+            x <- sapply(x, format, trim = TRUE, digits = digits, decimal.mark = panderOptions('decimal.mark')) #nolint
+        } else {
+            ## otherwise force using the same number format for all vector elements
+            x <- format(x, trim = TRUE, digits = digits, decimal.mark = panderOptions('decimal.mark'))
+        }
 
     }
 
     ## replace missing values
-    if (length(w) > 0)
+    if (length(w) > 0) {
         x[w] <- missing
+    }
 
-    if (x.len == 1)
+    if (x.len == 1) {
         wrap(x, wrap)
-    else if (x.len == 2)
+    } else if (x.len == 2) {
         paste(wrap(x, wrap), collapse = copula)
-    else
+    } else {
         paste0(paste(wrap(head(x, -1), wrap), collapse = sep), copula, wrap(tail(x, 1), wrap))
+    }
 }
 
 
@@ -106,8 +112,8 @@ p <- function(x, wrap = panderOptions('p.wrap'), sep = panderOptions('p.sep'), c
 #' @param wrap a string to wrap around vector elements
 #' @return a string with wrapped elements
 #' @examples \dontrun{
-#' wrap("foobar")
-#' wrap(c("fee", "fi", "foo", "fam"), "_")
+#' wrap('foobar')
+#' wrap(c('fee', 'fi', 'foo', 'fam'), '_')
 #' }
 #' @export
 #' @author Aleksandar Blagotic
@@ -136,8 +142,9 @@ has.rownames <- function(x) {
 #' @export
 set.caption <- function(x, permanent = FALSE){
     assign('caption', x , envir = storage)
-    if (!is.null(x))
+    if (!is.null(x)) {
         attr(storage$caption, 'permanent') <- permanent
+    }
 }
 
 
@@ -157,7 +164,7 @@ get.caption <- function()
 #' @param row.names string holding the alignment of the (optional) row names
 #' @param permanent (default \code{FALSE}) if alignment is permanent (for all future tables) or not. It's cleaner to use \code{panderOptions} instead.
 #' @export
-set.alignment <- function(default = panderOptions('table.alignment.default'), row.names = panderOptions('table.alignment.rownames'), permanent = FALSE) {
+set.alignment <- function(default = panderOptions('table.alignment.default'), row.names = panderOptions('table.alignment.rownames'), permanent = FALSE) { #nolint
     assign('alignment', list(default = default, row.names = row.names) , envir = storage)
     attr(storage$alignment, 'permanent') <- permanent
 }
@@ -177,18 +184,21 @@ get.alignment <- function(df) {
         if (is.null(a)) {
             ad <- panderOptions('table.alignment.default')
             ar <- panderOptions('table.alignment.rownames')
-            if (!has.rownames(df))
+            if (!has.rownames(df)) {
                 ar <- NULL
-            if (is.function(ar))
+            }
+            if (is.function(ar)) {
                 ar <- ar()
+            }
             if (is.function(ad)) {
                 return(c(ar, ad(df)))
             }
             a <- list(default = ad, row.names = ar)
         }
 
-        if (length(a) == 1)
+        if (length(a) == 1) {
             a <- list(default = as.character(a), row.names = as.character(a))
+        }
 
         if (length(dim(df)) < 2) {
             w <- length(df)
@@ -196,14 +206,16 @@ get.alignment <- function(df) {
         } else {
             w <- ncol(df)
             n <- rownames(df)
-            if (all(n == 1:nrow(df)))
+            if (all(n == 1:nrow(df))) {
                 n <- NULL
+            }
         }
 
-        if (is.null(n))
+        if (is.null(n)) {
             return(rep(a$default, length.out = w))
-        else
+        } else {
             return(c(a$row.names, rep(a$default, length.out = w)))
+        }
 
     }
 
@@ -215,7 +227,7 @@ get.alignment <- function(df) {
 #'
 #' Storing indexes of cells to be (strong) emphasized of a tabular data in an internal buffer that can be released and applied by \code{\link{pandoc.table}}, \code{\link{pander}} or \code{\link{evals}} later.
 #' @param x vector of row/columns indexes or an array like returned by \code{which(..., arr.ind = TRUE)}
-#' @aliases emphasize.rows emphasize.cols emphasize.cells emphasize.strong.rows emphasize.strong.cols emphasize.strong.cells
+#' @aliases emphasize.rows emphasize.cols emphasize.cells emphasize.strong.rows emphasize.strong.cols emphasize.strong.cells emphasize.italics.rows emphasize.italics.cols emphasize.italics.cells emphasize.verbatim.rows emphasize.verbatim.cols emphasize.verbatim.cells
 #' @usage
 #' emphasize.rows(x)
 #'
@@ -228,6 +240,18 @@ get.alignment <- function(df) {
 #' emphasize.strong.cols(x)
 #'
 #' emphasize.strong.cells(x)
+#'
+#' emphasize.italics.rows(x)
+#'
+#' emphasize.italics.cols(x)
+#'
+#' emphasize.italics.cells(x)
+#'
+#' emphasize.verbatim.rows(x)
+#'
+#' emphasize.verbatim.cols(x)
+#'
+#' emphasize.verbatim.cells(x)
 #' @export
 #' @examples \dontrun{
 #' n <- data.frame(x = c(1,1,1,1,1), y = c(0,1,0,1,0))
@@ -243,13 +267,25 @@ emphasize.rows <- function(x)
 #' @export
 emphasize.strong.rows <- emphasize.rows
 #' @export
+emphasize.italics.rows <- emphasize.rows
+#' @export
+emphasize.verbatim.rows <- emphasize.rows
+#' @export
 emphasize.cols <- emphasize.rows
 #' @export
 emphasize.strong.cols <- emphasize.rows
 #' @export
+emphasize.italics.cols <- emphasize.rows
+#' @export
+emphasize.verbatim.cols <- emphasize.rows
+#' @export
 emphasize.cells <- emphasize.rows
 #' @export
 emphasize.strong.cells <- emphasize.rows
+#' @export
+emphasize.italics.cells <- emphasize.rows
+#' @export
+emphasize.verbatim.cells <- emphasize.rows
 
 
 #' Get emphasize params from internal buffer
@@ -259,9 +295,22 @@ emphasize.strong.cells <- emphasize.rows
 #' @return R object passed as \code{df} with possibly added \code{attr}s captured from internal buffer
 #' @keywords internal
 get.emphasize <- function(df) {
-    for (v in c('emphasize.rows', 'emphasize.cols', 'emphasize.cells', 'emphasize.strong.rows', 'emphasize.strong.cols', 'emphasize.strong.cells'))
-        if (is.null(attr(df, v)))
+    for (v in c('emphasize.rows',
+                'emphasize.cols',
+                'emphasize.cells',
+                'emphasize.strong.rows',
+                'emphasize.strong.cols',
+                'emphasize.strong.cells',
+                'emphasize.italics.rows',
+                'emphasize.italics.cols',
+                'emphasize.italics.cells',
+                'emphasize.verbatim.rows',
+                'emphasize.verbatim.cols',
+                'emphasize.verbatim.cells')) {
+        if (is.null(attr(df, v))) {
             attr(df, v) <- get.storage(v)
+        }
+    }
     return(df)
 }
 
@@ -273,8 +322,9 @@ get.emphasize <- function(df) {
 #' @keywords internal
 get.storage <- function(what) {
     res <- tryCatch(get(what, envir = storage, inherits = FALSE), error = function(e) NULL)
-    if (is.null(attr(res, 'permanent')) || !attr(res, 'permanent'))
+    if (is.null(attr(res, 'permanent')) || !attr(res, 'permanent')) {
         assign(what, NULL , envir = storage)
+    }
     return(res)
 }
 
@@ -287,14 +337,13 @@ get.storage <- function(what) {
 #' @export
 add.significance.stars <- function(p) {
 
-    if (inherits(p, c("matrix", "data.frame")) && length(dim(p)) == 2) {
+    if (inherits(p, c('matrix', 'data.frame')) && length(dim(p)) == 2) {
         apply(p, c(1,2), add.significance.stars)
     } else {
         if (length(p) > 1) {
             sapply(p, add.significance.stars)
         } else {
-            s <- ifelse(p > 0.05, '', ifelse(p > 0.01, ' *', ifelse(p > 0.001, ' * *', ' * * *')))
-            paste0(p(p), s)
+            ifelse(p > 0.05, '', ifelse(p > 0.01, ' *', ifelse(p > 0.001, ' * *', ' * * *')))
         }
     }
 }
@@ -325,20 +374,25 @@ cache.on <- function()
 #' @return character string with line breaks
 #' @export
 #' @examples
-#' splitLine("foo bar", 6)
-#' splitLine("foo bar", 7)
-#' splitLine("Pandoc Package", 3, TRUE)
+#' splitLine('foo bar', 6)
+#' splitLine('foo bar', 7)
+#' splitLine('Pandoc Package', 3, TRUE)
 splitLine <- function(x, max.width = panderOptions('table.split.cells'), use.hyphening = FALSE) {
-    if (any(is.na(x)))
+    if (any(is.na(x))) {
         return(x)
-    if (!is.character(x) || !is.null(dim(x)) || length(x) != 1 || x == "")
+    }
+    if (!is.character(x) || !is.null(dim(x)) || length(x) != 1 || x == '') {
         return(x)
-    if (suppressWarnings(!is.na(as.numeric(x))))
+    }
+    if (suppressWarnings(!is.na(as.numeric(x)))) {
         return(x)
-    if (is.infinite(max.width))
+    }
+    if (is.infinite(max.width)) {
         max.width <- .Machine$integer.max
-    if (use.hyphening && !requireNamespace('koRpus', quietly = TRUE))
+    }
+    if (use.hyphening && !requireNamespace('koRpus', quietly = TRUE)) {
         use.hyphening <- FALSE
+    }
     hyphen_f <- function(s)
         koRpus::hyphen(s, hyph.pattern = 'en.us', quiet = TRUE)@hyphen[1, 2]
     .Call('pander_splitLine_cpp', PACKAGE = 'pander', x, max.width, use.hyphening, hyphen_f)
@@ -351,9 +405,87 @@ splitLine <- function(x, max.width = panderOptions('table.split.cells'), use.hyp
 #' @keywords internal
 check_caption <- function(caption) {
 
-    if (length(caption) > 1)
+    if (length(caption) > 1) {
         stop('The caption should be exactly one string.')
+    }
 
-    if (!(is.character(caption) | is.null(caption)))
+    if (!(is.character(caption) | is.null(caption))){
         stop('The caption should be string (character class) or NULL.')
+    }
+}
+
+
+#' Check if vector parameter for round/digits and adjust accodingly
+#' @param param vector to be checked
+#' @param name parameter name
+#' @param n needed size of vector
+#' @return original vector if size is good, vector of default values otherwise
+#' @keywords internal
+check_digits <- function(param, name, n) {
+    if (length(param) == 1) {
+        param <- rep(param, n)
+    } else if (length(param) < n) {
+        warning(sprintf('%s is not equal to ncol(t), reverting to default value', name))
+        param <- rep(panderOptions(name), n)
+    }
+    param
+}
+
+#' Create a multitable used for rendering objects from rms package
+#'
+#' When ols/lrm/orm from rms package get rendered, main statistics are group in table of tables.
+#' Since pandoc doesn't support row or col-span,
+#' we chose to group those statistics in a column each.
+#' This function takes care of that
+#' @param v list of vectors/lists to be merge in the table
+#' @return data.frame in specified format
+#' @examples
+#' pander:::multitable(list(list(a=1, b=2),list(c=3, d=4)))
+#' @keywords internal
+multitable <- function(v) {
+    ml <- max(sapply(v, length))
+    mod <- lapply(1:length(v),
+                  function(i)  {
+                      uv <- unlist(c(rbind(pandoc.strong.return(names(v[[i]])),
+                                           sapply(v[[i]], p, wrap=''))))
+                      if (length(v[[i]]) < ml)
+                          uv <- c(uv, rep('', 2 * (ml - length(v[[i]]))))
+                      uv
+                  })
+    do.call(cbind, mod)
+}
+
+#' Calculate coef matrix for models from rms package
+#' Forked from prModFit from rms
+#'
+#' @param obj object list
+#' @param coefs numeric value if to print only the first n regression coefficients in the model.
+#' @return coeficients matrix
+#' @importFrom stats pt pchisq
+coef_mat <- function(obj, coefs) {
+    errordf <- obj$errordf
+    beta <- obj$coef
+    se <- obj$se
+    Z <- beta / se
+    if(length(errordf)) {
+        P <- 2 * (1 - pt(abs(Z), errordf))
+    } else {
+        P <- 1 - pchisq(Z ^ 2, 1)
+    }
+    U <- cbind(beta, se, Z, P)
+    colnames(U) <- c('Coef', 'S.E.', 'Wald Z', 'Pr(>|Z|)')
+    if (length(errordf)) {
+        colnames(U)[3:4] <- c('t', 'Pr(>|t|)')
+    }
+    rownames(U) <- names(beta)
+    if (length(obj$aux)) {
+        U <- cbind(U, obj$aux)
+        colnames(U)[ncol(U)] <- obj$auxname
+    }
+    if (is.numeric(coefs)) {
+        U <- U[1:coefs, , drop = FALSE]
+        U <- rbind(U, rep('', ncol(U)))
+        rownames(U)[nrow(U)] <- '. . .'
+    }
+    U
 }
